=============================
Authors of the Lino framework
=============================

The Lino framework was originally started in 2004 by Luc Saffre, who is the main
contributor and maintainer since then.

All major contributors agreed to have their copyright assigned to Rumma & Ko
Ltd. See https://dev.lino-framework.org/contrib/legal.html

Major contributors
==================

Hamza Khchine <hamzakhchine@gmail.com>
Sharif Mehedi <sharifmehedi24@yahoo.com>
Tonis Piip <tonis.piip@gmail.com>
Luc Saffre <luc@saffre-rumma.net>

Minor contributors
==================

Mahmoud Abbas <sharedup@gmail.com>
Subha Bera <subha4exam@gmail.com>
Flavio Gondin <flvgondin@gmail.com> (:blogref:`20130622`, :blogref:`20130623`)
Conrad Großer <grosserconrad@gmail.com>
Josef Kejzlar <joe@wpj.cz> <cuchac@email.cz> (:blogref:`20130701`)
Rauno Lipp <raunolipp@gmail.com>
Sandeep Sawant <sandeepsawant22@gmail.com> (:blogref:`20150610`)
Manuel Weidmann (Code Gears) <info@code-gears.com>
